// const crypto = require("crypto");
const { promisify } = require("util");
const jwt = require("jsonwebtoken");
const User = require("../models/userModel");
const catchAsync = require("../utils/catchAsync");
const AppError = require("../utils/appError");

const signToken = (id, email, firstName) =>
  jwt.sign({ id, email, firstName }, process.env.JWT_SECRET, {
    expiresIn: process.env.JWT_EXPIRE_IN,
  });

const createSendToken = (user, statusCode, res) => {
  const token = signToken(user.id, user.email, user.firstName);
  const cookieOptions = {
    expires: new Date(
      Date.now() + process.env.JWT_COOKIE_EXPIRE_IN * 24 * 60 * 60 * 1000
    ),
    httpOnly: true,
  };
  if (process.env.NODE_ENV === "production") cookieOptions.secure = true;

  res.cookie("jwt", token, cookieOptions);

  //! Remove password from output
  user.password = undefined;

  res.status(statusCode).json({
    status: "success",
    token,
    user,
  });
};

exports.signup = catchAsync(async (req, res, next) => {
  const newUser = await User.create(req.body);
  console.log(newUser);

  // await new
  //  Email(newUser).sendWelcome();

  createSendToken(newUser, 201, res);
});

exports.login = catchAsync(async (req, res, next) => {
  const { email, password } = req.body;
  console.log(email, password);

  //! Check if email or password exist
  if (!email || !password) {
    return next(new AppError("Please provide email and password!", 400));
  }

  //! Check if user exists && password is correct
  const user = await User.findOne({ email }).select("+password");
  console.log("User", user);

  if (!user || !(await user.correctPassword(password, user.password)))
    return next(new AppError("Incorrect email or password", 401));

  //! If everything ok, send the token to client
  createSendToken(user, 200, res);
});

exports.protect = catchAsync(async (req, res, next) => {
  //! Getting token and check of it's there
  let token;
  if (
    req.headers.authorization &&
    req.headers.authorization.startsWith("Bearer")
  )
    token = req.headers.authorization.split(" ")[1];

  if (!token)
    return next(
      new AppError("You are not logged in! Please log in to get access", 401)
    );

  //! Verification token
  const decode = await promisify(jwt.verify(token, process.env.JWT_SECRET));

  //! Check if user is still exists
  const freshUser = await User.findById(decode.id);
  if (!freshUser)
    return next(
      new AppError(
        "The user belonging to this token does no longer exist.",
        401
      )
    );

  //! Grant access to protect route
  req.user = freshUser;

  next();
});

exports.sendEmail = catchAsync(async (req, res, next) => {
  // await sendEmail({
  //   email: "dgajjar999@gmail.com",
  //   subject: "Testing email",
  //   message: "This is testing mail ",
  // });
  // res.status(200).json({
  //   status: "success",
  //   message: "email is sended",
  // });
});
